@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_P_H__
-#define __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_P_H__
+#pragma once
 
 #include <gpgme++/global.h>
 
@@ -79,4 +78,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_P_H__
